/*
   _===_ _           _                  ______ _     _             _ _ _
  |  ___| |         | |                 | ___ (_)   | |           (_) | |
  | |__ | | ___  ___| |_ _ __ ___ ______| |_/ /_  __| | ___  _   _ _| | | ___ _   _ _ __
  |  __|| |/ _ \/ __| __| '__/ _ \______| ___ \ |/ _` |/ _ \| | | | | | |/ _ \ | | | '__|
  | |___| |  __/ (__| |_| | | (_) |     | |_/ / | (_| | (_) | |_| | | | |  __/ |_| | |
  \____/|_|\___|\___|\__|_|  \___/      \____/|_|\__,_|\___/ \__,_|_|_|_|\___|\__,_|_|

  Boîtier de L'Horloge UTC Exacte.
  Développé dans OpenSCAD.
  Électro-Bidouilleur, Janvier 2022   https://www.youtube.com/Électro-Bidouilleur
  Licence de droits: Attribution 4.0 International (CC BY 4.0)  Lisez https://creativecommons.org/licenses/by/4.0/deed.fr  
*/

length_size = 85;
width_size = 41.25;
height_size = 34.5;
wall_thickness = 2;
hole_diameter  = 5;
post_diameter = 6;
screw_diameter = 3;

// Creation de la boîte
difference() 
{
    // Creation de la boîte avec un autre parallepipede
    linear_extrude(height = height_size, center = true)
    color("gray")  square(size=[length_size, width_size] , center = true);  // 

    // Vidage de la boîte avec un autre parallepipede
    translate([0, 0, wall_thickness])
    linear_extrude(height = height_size-wall_thickness, center = true)
    square(size=[length_size-wall_thickness*2, width_size-wall_thickness*2] , center = true); 

    //Soustraction du trou de l'affichage
    translate([0, -0.5, -20])
    linear_extrude(height = height_size, center = true)
    square(size=[60, 12.5] , center = true);

    //Soustraction du recess de l'affichage
    translate([0, -0.5, 0])
    linear_extrude(height = 34, center = true)
    square(size=[72, 24.7] , center = true);

    //Soustraction du connecteur USB
    rotate([90,0,90])
    translate([2, 15.25, -16]) // y,z,x
    linear_extrude(height = 100, center = true)
    square(size=[8.3, 4.5] , center = true);
}

//Creation du couvercle
difference() 
{
    translate([0, 0, -(height_size/2-1)])       // Cela amène le couvercle au mème niveau que la boîte
    union()
    {
        // Création de la Plaque
        difference()
        {
            // Surface plane
            translate([0, -(width_size+5),0])
            linear_extrude(height = wall_thickness, center = true)
            square(size=[length_size, width_size] , center = true) ; 
    
            //Soustraction du trou du connecteur SMA
            translate([-(length_size/2 -39), -(width_size+5 - width_size/2 + 9),-0])  // x,y,z
            cylinder($fn=360,h=50, d=6.5, center=true);

            //Soustraction du trou #1 pour les autres cables
            translate([-(length_size/2 -30), -(width_size+5 - width_size/2 + 9),-0])  // x,y,z
            cylinder($fn=360,h=50, d=4, center=true);

            //Soustraction du trou # 2 pour les autres cables
            translate([-(length_size/2 -22), -(width_size+5 - width_size/2 + 9),-0])  // x,y,z
            cylinder($fn=360,h=50, d=4, center=true);
        }
        
        // Créaton de la bordure interne de la plaque
        difference()
        {
            // Boîte créant la bordure
            translate([0, -(width_size+5),wall_thickness])
            linear_extrude(height = wall_thickness+1, center = true)
            square(size=[length_size-(2*wall_thickness+0.5), width_size-(2*wall_thickness+0.5)] , center = true); 
            
            // Soustraction de la boîte interne. Cela ne laisse que la bordure mince
            translate([0, -(width_size+5),wall_thickness])
            linear_extrude(height = wall_thickness+1.2, center = true)
            square(size=[length_size-(2*wall_thickness+0.5)-2, width_size-(2*wall_thickness+0.5)-2] , center = true);

            //Soustraction du connecteur USB de la bordure
            translate([-50, -(width_size+5+2),wall_thickness])  // x,y,z
            rotate([90,0,90])
            linear_extrude(height = 100, center = true)
            square(size=[8.3, 4.5] , center = true);
        }   
    }       
 }        
        